<#
* Copyright(c) 2006-2016 ThreatSTOP, Inc. All Rights Reserved
* NOTICE: All information contained herein is, and remains the property of ThreatSTOP, Inc. and its suppliers, if any. The intellectual and
* technical concepts contained herein are proprietary to ThreatSTOP, Inc. and its suppliers and certain aspects thereof are protected by United
* States Patent No. 8,533,822 and United States Patent No. 8,869,237, and are protected by trade secret or copyright law.
* US Government Entities: The ThreatSTOP service, software and documentation, as applicable, are "commercial computer software" and
* "commercial computer software documentation" developed exclusively at private expense by Threatstop, Inc. ("Threatstop"). Pursuant to FAR
* 12.212 or DFARS 227 7202 and their successors, as applicable, use, reproduction and disclosure of the software and documentation is
* governed by the terms of Threatstop's commercial agreement.
#>
# ErrID start: 60
#
# 1. use dig to get zone using TSIG. Requires dig.exe installation, C++ runtime.
# 2. save to file
# 3. run apply script

#Load config values into hash table:
$scriptPath = split-path -parent $MyInvocation.MyCommand.Definition
$iniPath = (get-item $scriptPath).parent.fullname
. "$scriptPath\functions.ps1"
$ini = Get-IniContent ($iniPath + "\ThreatSTOP.ini")
$tsig = $ini["Dig"].TSIG
$dig = $ini["Dig"].DigExe
$policy = $ini["General"].TSZoneName
$dns_servers = $ini["General"].TSMaster
$zonefolder = $ini["General"].TSZoneFolder

#create Zone folder if missing
if (!(Test-Path $zonefolder))
{
    New-Item -ItemType Directory -Force -Path $zonefolder
}

$zone_out = "$zonefolder\$policy.dns"
foreach ($dns_server in $dns_servers -split ';') {
    &$dig `"@$dns_server`" -t axfr -y $tsig $policy | Out-File -FilePath "$zone_out"
    if (Test-Path $zone_out)
    {
        Write-Host("Checking $zone_out file")
    }
    else
    {
        Write-Host ("$zone_out not found.")
        continue;
    }
    if ((Get-Item $zone_out).length -lt 5kb )
    {
        #include first line of zone file when reporting error
        $fl = ""
        try{
            $fl = Get-Content $zone_out -First 1
        }
        catch{}
        $msg = "Zone ($policy) may not live on this dns_server ($dns_server) or have transferred incorrectly. Additional info: $fl"
        # Write-EventLog -LogName Application -Source 'ThreatSTOP' -EntryType Error -EventId 21 -Message $msg
        Write-Host $msg
        Write-Host -ForegroundColor Cyan 'Trying next dns_server'
        continue;
    } else {
        Write-Host -ForegroundColor Green "Validated $zone_out looks good to be applied"
        & ((Split-Path $MyInvocation.InvocationName) + "\applyTSpolicy.ps1")
        break;
    }
}